Installation
============

From PyPI
---------

To install PyEconomics, use `pip`:

.. code-block:: sh

   pip install pyeconomics

From Source
-----------

If you want to install the package from the source code, follow these steps:

1. Clone the repository:

   .. code-block:: sh

      git clone https://github.com/nathanramoscfa/pyeconomics.git

2. Change to the project directory:

   .. code-block:: sh

      cd pyeconomics

3. Install the package:

   .. code-block:: sh

      pip install .
